import type { MdocVerifyOptions } from './MdocOptions';
import type { MdocRecord } from './repository';
import type { Query, QueryOptions } from '../../storage/StorageService';
import { AgentContext } from '../../agent';
import { Mdoc } from './Mdoc';
import { MdocService } from './MdocService';
/**
 * @public
 */
export declare class MdocApi {
    private agentContext;
    private mdocService;
    constructor(agentContext: AgentContext, mdocService: MdocService);
    /**
     *
     * Verify an incoming mdoc. It will check whether everything is valid, but also returns parts of the validation.
     *
     * For example, you might still want to continue with a flow if not all the claims are included, but the signature is valid.
     *
     */
    verify(options: MdocVerifyOptions): Promise<{
        isValid: boolean;
        error: string;
    } | {
        isValid: boolean;
        error?: undefined;
    }>;
    /**
     * Create an Mdoc class from a hex encoded Mdoc Issuer-Signed structure
     */
    fromIssuerSignedHex(hexEncodedMdoc: string): Mdoc;
    /**
     * Create an Mdoc class from a hex encoded Mdoc Issuer-Signed structure
     */
    fromIssuerSignedBase64Url(base64UrlEncodedMdoc: string): Mdoc;
    store(mdoc: Mdoc): Promise<MdocRecord>;
    getById(id: string): Promise<MdocRecord>;
    getAll(): Promise<Array<MdocRecord>>;
    findAllByQuery(query: Query<MdocRecord>, queryOptions?: QueryOptions): Promise<Array<MdocRecord>>;
    deleteById(id: string): Promise<void>;
    update(mdocRecord: MdocRecord): Promise<void>;
}
