"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.MdocCoseCallbackService = void 0;
const kmp_mdl_mdoc_1 = require("@sphereon/kmp-mdl-mdoc");
const transform_1 = require("../../crypto/jose/jwk/transform");
const TypedArrayEncoder_1 = require("../../utils/TypedArrayEncoder");
const MdocError_1 = require("./MdocError");
const mdlJwk = kmp_mdl_mdoc_1.com.sphereon.jose.jwk.Jwk;
/**
 * This class can be used for Cose signing and sigature verification.
 * Either have an instance per trustedCerts and verification invocation or use a single instance and provide the trusted certs in the method argument
 *
 * The class is also registered with the low-level mDL/mdoc Kotlin Multiplatform library
 * Next to the specific function for the library it exports a more powerful version of the same verification method as well
 */
class MdocCoseCallbackService {
    constructor(agentContext) {
        this.agentContext = agentContext;
    }
    async sign1(
    // eslint-disable-next-line @typescript-eslint/no-unused-vars
    coseCborInput, 
    // eslint-disable-next-line @typescript-eslint/no-unused-vars
    keyInfo) {
        throw new MdocError_1.MdocError('Method not yet implemented');
    }
    /**
     * This method is the implementation used within the mDL/Mdoc library
     */
    async verify1(input, keyInfo) {
        var _a, _b, _c, _d;
        const sign1Json = input.toJson(); // Let's make it a bit easier on ourselves, instead of working with CBOR
        const coseAlg = sign1Json.protectedHeader.alg;
        if (!coseAlg) {
            return Promise.reject(Error('No alg protected header present'));
        }
        if (!(keyInfo === null || keyInfo === void 0 ? void 0 : keyInfo.opts))
            throw new MdocError_1.MdocError('Mdoc Verification Callback missing keyInfo.');
        const kid = (_b = (_a = keyInfo === null || keyInfo === void 0 ? void 0 : keyInfo.kid) !== null && _a !== void 0 ? _a : sign1Json.protectedHeader.kid) !== null && _b !== void 0 ? _b : (_c = sign1Json.unprotectedHeader) === null || _c === void 0 ? void 0 : _c.kid;
        const publicKey = (_d = keyInfo.opts) === null || _d === void 0 ? void 0 : _d.asJsReadonlyMapView().get('publicKey');
        if (!publicKey)
            new MdocError_1.MdocError('Mdoc Verification Callback missing publicKey Jwk.');
        const publicKeyJwk = (0, transform_1.getJwkFromKey)(publicKey).toJson();
        const coseKey = mdlJwk.Companion.fromJsonObject(publicKeyJwk).jwkToCoseKeyJson();
        const recalculatedToBeSigned = input.toBeSignedJson(coseKey, coseAlg);
        const valid = await this.agentContext.wallet.verify({
            key: publicKey,
            signature: TypedArrayEncoder_1.TypedArrayEncoder.fromBase64(sign1Json.signature),
            data: TypedArrayEncoder_1.TypedArrayEncoder.fromHex(recalculatedToBeSigned.hexValue),
        });
        return {
            name: 'cose-verification',
            message: valid ? 'cose-signature successfully validated' : 'cose-signature could not be validated',
            keyInfo: keyInfo !== null && keyInfo !== void 0 ? keyInfo : { kid, key: coseKey.toCbor() },
            critical: !valid,
            error: !valid,
        };
    }
}
exports.MdocCoseCallbackService = MdocCoseCallbackService;
//# sourceMappingURL=MdocCoseCallbackService.js.map