"use strict";
var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
var __metadata = (this && this.__metadata) || function (k, v) {
    if (typeof Reflect === "object" && typeof Reflect.metadata === "function") return Reflect.metadata(k, v);
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.MdocService = void 0;
const tsyringe_1 = require("tsyringe");
const utils_1 = require("../../utils");
const x509_1 = require("../x509");
const Mdoc_1 = require("./Mdoc");
const MdocError_1 = require("./MdocError");
const repository_1 = require("./repository");
/**
 * @internal
 */
let MdocService = class MdocService {
    constructor(mdocRepository) {
        this.MdocRepository = mdocRepository;
    }
    fromHexEncodedMdoc(hexEncodedMdoc) {
        return Mdoc_1.Mdoc.fromIssuerSignedHex(hexEncodedMdoc);
    }
    fromBase64UrlEncodedMdoc(base64UrlEncodedMdoc) {
        const hexEncodedMdoc = utils_1.TypedArrayEncoder.fromBase64(base64UrlEncodedMdoc).toString('hex');
        return Mdoc_1.Mdoc.fromIssuerSignedHex(hexEncodedMdoc);
    }
    async verify(agentContext, { mdoc }) {
        const { trustedCertificates } = agentContext.dependencyManager.resolve(x509_1.X509ModuleConfig);
        if (!trustedCertificates) {
            throw new MdocError_1.MdocError('Mdoc Verification failed. Missing trusted certificates.');
        }
        return await mdoc.verify(agentContext, { trustedCertificates });
    }
    async store(agentContext, mdoc) {
        const mdocRecord = new repository_1.MdocRecord({ mdoc });
        await this.MdocRepository.save(agentContext, mdocRecord);
        return mdocRecord;
    }
    async getById(agentContext, id) {
        return await this.MdocRepository.getById(agentContext, id);
    }
    async getAll(agentContext) {
        return await this.MdocRepository.getAll(agentContext);
    }
    async findByQuery(agentContext, query, queryOptions) {
        return await this.MdocRepository.findByQuery(agentContext, query, queryOptions);
    }
    async deleteById(agentContext, id) {
        await this.MdocRepository.deleteById(agentContext, id);
    }
    async update(agentContext, mdocRecord) {
        await this.MdocRepository.update(agentContext, mdocRecord);
    }
};
exports.MdocService = MdocService;
exports.MdocService = MdocService = __decorate([
    (0, tsyringe_1.injectable)(),
    __metadata("design:paramtypes", [repository_1.MdocRepository])
], MdocService);
//# sourceMappingURL=MdocService.js.map